==> steampipe_alchemy-0.1.3.tar.gz: steampipe_alchemy-0.1.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""
from pathlib import Path

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = Path('requirements.txt').read_text().splitlines()
requirements = list(filter(lambda p: not p.startswith('-e'), requirements))

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Ryan Gerstenkorn",
    author_email='ryan.gerstenkorn@rhinosecuritylabs.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Python Boilerplate contains all the boilerplate you need to create a Python package.",
    install_requires=requirements,
    license="BSD license",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/x-rst",
    include_package_data=True,
    keywords='steampipe_alchemy',
    name='steampipe_alchemy',
    packages=find_packages(include=['steampipe_alchemy', 'steampipe_alchemy.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/RyanJarv/steampipe_alchemy',
    version='0.1.3',
    zip_safe=False,
)

==> steampipe_alchemy-0.1.4.tar.gz: steampipe_alchemy-0.1.4/setup.py <==
#!/usr/bin/env python

"""The setup script."""
from pathlib import Path

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = (Path(__file__).parent/'requirements.txt').read_text().splitlines()

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Ryan Gerstenkorn",
    author_email='ryan.gerstenkorn@rhinosecuritylabs.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Python Boilerplate contains all the boilerplate you need to create a Python package.",
    install_requires=requirements,
    license="BSD license",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/x-rst",
    include_package_data=True,
    keywords='steampipe_alchemy',
    name='steampipe_alchemy',
    packages=find_packages(include=['steampipe_alchemy', 'steampipe_alchemy.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/RyanJarv/steampipe_alchemy',
    version='0.1.4',
    zip_safe=False,
)
